import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import requests
from bs4 import BeautifulSoup


class Player(object):

    def __init__(self, player_name):
        # use
        self.url = "http://search.espncricinfo.com/ci/content/player/search.html?search=" + \
            player_name.lower().replace(" ", "+") + "&x=0&y=0"
        self.page = requests.get(self.url)
        self.soup = BeautifulSoup(self.page.content, "html.parser")
        self.player_id = str(self.soup.find_all(class_='ColumnistSmry')
                             [0]).split('.html')[0].split('/')[-1]
        self.url_2 = f'https://www.espncricinfo.com/player/player-name-{self.player_id}'
        self.page_2 = requests.get(self.url_2)
        self.soup2 = BeautifulSoup(self.page_2.content, "html.parser")

        self.temp_url = 'https://www.espncricinfo.com/player/player-name-{self.player_id}/tests-odi-t20-records'
        self.temp_page = requests.get(self.temp_url)
        self.temp_soup = BeautifulSoup(self.temp_page.content, "html.parser")

    def get_format_df(self, format_num, view, action):
        df = pd.read_html(
            f'https://stats.espncricinfo.com/ci/engine/player/{self.player_id}.html?class={format_num};template=results;type={action};view={view}')[3]
        return df

    def get_summary_stats(self, format_num, view, action):
        summary_df = pd.read_html(
            f'https://stats.espncricinfo.com/ci/engine/player/{self.player_id}.html?class={format_num};template=results;type={action};view={view}')[2]
        return summary_df

    def get_overall_df(self, type_num, view, action):
        overall_df = pd.read_html(
            f'https://stats.espncricinfo.com/ci/engine/player/{self.player_id}.html?class=11;template=results;type={action};view={view}')[type_num]
        return overall_df

    def get_career_df(self):
        # print(self.url)
        personal_df = pd.read_html(self.url_2)[0]
        return personal_df

    def get_personal_info(self, arg):
        # for item in self.soup2.findAll('span', {'class': 'ds-text-title-s ds-font-bold'}):
        #     items.append(item)
        results = self.soup2.find(id="__next")
        job_elements = results.find_all(
            "div", class_="ds-grid lg:ds-grid-cols-3 ds-grid-cols-2 ds-gap-4 ds-mb-8")
        text_list = []
        for job_element in job_elements:
            for i in job_element:
                for element in i:
                    text_list.append(element.text)
        print(text_list)
        if arg == "full_name":
            return text_list[1]
        elif arg == "birth_info":
            return text_list[3]
        elif arg == "age":
            return text_list[5]
        elif arg == "batting_style":
            return text_list[7]
        elif arg == "bowling_style":
            return text_list[9]
        elif arg == "playing_role":
            return text_list[11]
        # print(list1)

        #     "span", class_="ds-text-title-s ds-font-bold ds-text-ui-typo")
        # return elements
    def get_teams(self):
        results = self.soup2.find(id="__next")
        job_elements = results.find_all(
            "div", class_="ds-grid lg:ds-grid-cols-3 ds-grid-cols-2 ds-gap-y-4")
        text_list = []
        for job_element in job_elements:
            for i in job_element:
                for element in i:
                    text_list.append(element.text)
        for i in text_list:
            if i == '':
                text_list.remove(i)
        return text_list

    def get_description(self):
        results = self.soup2.find(id="__next")
        job_elements = results.find_all(
            "div", class_="ds-relative ds-overflow-hidden ds-mt-6")
        text_list = []
        for job_element in job_elements:
            for i in job_element:
                for element in i:
                    text_list.append(element.text)
        for i in text_list:
            if i == '':
                text_list.remove(i)
        return text_list

    def get_overview_df(self, pos):
        df = pd.read_html(
            f'https://www.espncricinfo.com/player/player-name-{self.player_id}')[pos]
        return df


print(Player('Mithali Raj').get_description())



from CricCatapult.Series import Series
from CricCatapult.Records import Records
from CricCatapult.Location import Records
from CricCatapult.cricsheet import cricsheet
from CricCatapult.Player import Player
from CricCatapult.Scoreboard import Scoreboard



import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import requests
import zipfile
import io
from bs4 import BeautifulSoup

class Cricsheet(object):
    def __init__(self):
        self.url = "https://cricsheet.org/downloads/"
        self.page = requests.get(self.url)
        self.soup = BeautifulSoup(self.page.content, "html.parser")
    def all_matches_json(self):
        link = "https://cricsheet.org/downloads/all_json.zip"
        link = requests.get(link)
        zip = zipfile.ZipFile(io.BytesIO(link.content))
        zip.extractall()
    def all_matches_yaml(self):
        link = "https://cricsheet.org/downloads/all.zip"
        link = requests.get(link)
        zip = zipfile.ZipFile(io.BytesIO(link.content))
        zip.extractall()
    def all_matches_csv(self, gender):
        if gender == "male":
            link = "https://cricsheet.org/downloads/all_male_csv.zip"
            link = requests.get(link)
            zip = zipfile.ZipFile(io.BytesIO(link.content))
            zip.extractall()
        elif gender == "women":
            link = "https://cricsheet.org/downloads/all_female_csv.zip"
            link = requests.get(link)
            zip = zipfile.ZipFile(io.BytesIO(link.content))
            zip.extractall()
        else:
            link = "https://cricsheet.org/downloads/all_csv.zip"
            link = requests.get(link)
            zip = zipfile.ZipFile(io.BytesIO(link.content))
            zip.extractall()
    def all_matches_csv2(self, gender):
        if gender == "male":
            link = "https://cricsheet.org/downloads/all_male_csv2.zip"
            link = requests.get(link)
            zip = zipfile.ZipFile(io.BytesIO(link.content))
            zip.extractall()
        elif gender == "women":
            link = "https://cricsheet.org/downloads/all_female_csv2.zip"
            link = requests.get(link)
            zip = zipfile.ZipFile(io.BytesIO(link.content))
            zip.extractall()
        else:
            link = "https://cricsheet.org/downloads/all_csv2.zip"
            link = requests.get(link)
            zip = zipfile.ZipFile(io.BytesIO(link.content))
            zip.extractall()
    def test_matches_csv(self, gender):
        if gender == "male" or gender == "men":
            link = "https://cricsheet.org/downloads/tests_male_csv.zip"
            link = requests.get(link)
            zip = zipfile.ZipFile(io.BytesIO(link.content))
            zip.extractall()
        elif gender == "women" or gender == "female":
            link = "https://cricsheet.org/downloads/tests_female_csv.zip"
            link = requests.get(link)
            zip = zipfile.ZipFile(io.BytesIO(link.content))
            zip.extractall()
        else:
            link = "https://cricsheet.org/downloads/tests_csv.zip"
            link = requests.get(link)
            zip = zipfile.ZipFile(io.BytesIO(link.content))
            zip.extractall()
    def test_matches_csv2(self, gender):
        if gender == "male" or gender == "men":
            link = "https://cricsheet.org/downloads/tests_male_csv2.zip"
            link = requests.get(link)
            zip = zipfile.ZipFile(io.BytesIO(link.content))
            zip.extractall()
        elif gender == "women" or gender == "female":
            link = "https://cricsheet.org/downloads/tests_female_csv2.zip"
            link = requests.get(link)
            zip = zipfile.ZipFile(io.BytesIO(link.content))
            zip.extractall()
        else:
            link = "https://cricsheet.org/downloads/tests_csv2.zip"
            link = requests.get(link)
            zip = zipfile.ZipFile(io.BytesIO(link.content))
            zip.extractall()
    def odi_csv(self, gender):
        if gender == "male" or gender == "men":
            link = "https://cricsheet.org/downloads/odis_male_csv.zip"
            link = requests.get(link)
            zip = zipfile.ZipFile(io.BytesIO(link.content))
            zip.extractall()
        elif gender == "women" or gender == "female":
            link = "https://cricsheet.org/downloads/odis_female_csv.zip"
            link = requests.get(link)
            zip = zipfile.ZipFile(io.BytesIO(link.content))
            zip.extractall()
        else:
            link = "https://cricsheet.org/downloads/odis_csv.zip"
            link = requests.get(link)
            zip = zipfile.ZipFile(io.BytesIO(link.content))
            zip.extractall()
    def odi_csv2(self, gender):
        if gender == "male" or gender == "men":
            link = "https://cricsheet.org/downloads/odis_male_csv2.zip"
            link = requests.get(link)
            zip = zipfile.ZipFile(io.BytesIO(link.content))
            zip.extractall()
        elif gender == "women" or gender == "female":
            link = "https://cricsheet.org/downloads/odis_female_csv2.zip"
            link = requests.get(link)
            zip = zipfile.ZipFile(io.BytesIO(link.content))
            zip.extractall()
        else:
            link = "https://cricsheet.org/downloads/odis_csv2.zip"
            link = requests.get(link)
            zip = zipfile.ZipFile(io.BytesIO(link.content))
            zip.extractall()
    def t20_csv(self, gender):
        if gender == "male" or gender == "men":
            link = "https://cricsheet.org/downloads/t20s_male_csv.zip"
            link = requests.get(link)
            zip = zipfile.ZipFile(io.BytesIO(link.content))
            zip.extractall()
        elif gender == "women" or gender == "female":
            link = "https://cricsheet.org/downloads/t20s_female_csv.zip"
            link = requests.get(link)
            zip = zipfile.ZipFile(io.BytesIO(link.content))
            zip.extractall()
        else:
            link = "https://cricsheet.org/downloads/t20s_csv.zip"
            link = requests.get(link)
            zip = zipfile.ZipFile(io.BytesIO(link.content))
            zip.extractall()
    def t20_csv2(self, gender):
        if gender == "male" or gender == "men":
            link = "https://cricsheet.org/downloads/t20s_male_csv2.zip"
            link = requests.get(link)
            zip = zipfile.ZipFile(io.BytesIO(link.content))
            zip.extractall()
        elif gender == "women" or gender == "female":
            link = "https://cricsheet.org/downloads/t20s_female_csv2.zip"
            link = requests.get(link)
            zip = zipfile.ZipFile(io.BytesIO(link.content))
            zip.extractall()
        else:
            link = "https://cricsheet.org/downloads/t20s_csv2.zip"
            link = requests.get(link)
            zip = zipfile.ZipFile(io.BytesIO(link.content))
            zip.extractall()
    def afghanleague_csv(self):
        link = "https://cricsheet.org/downloads/apl_csv.zip"
        link = requests.get(link)
        zip = zipfile.ZipFile(io.BytesIO(link.content))
        zip.extractall()
    def afghanleague_csv2(self):
        link = "https://cricsheet.org/downloads/apl_csv2.zip"
        link = requests.get(link)
        zip = zipfile.ZipFile(io.BytesIO(link.content))
        zip.extractall()
    def bigbashleague_csv(self):
        link = "https://cricsheet.org/downloads/bbl_csv.zip"
        link = requests.get(link)
        zip = zipfile.ZipFile(io.BytesIO(link.content))
        zip.extractall()
    def bigbashleague_csv2(self):
        link = "https://cricsheet.org/downloads/bbl_csv2.zip"
        link = requests.get(link)
        zip = zipfile.ZipFile(io.BytesIO(link.content))
        zip.extractall()
    def bangladeshleague_csv(self):
        link = "https://cricsheet.org/downloads/bpl_csv.zip"
        link = requests.get(link)
        zip = zipfile.ZipFile(io.BytesIO(link.content))
        zip.extractall()
    def bangladeshleague_csv2(self):
        link = "https://cricsheet.org/downloads/bpl_csv2.zip"
        link = requests.get(link)
        zip = zipfile.ZipFile(io.BytesIO(link.content))
        zip.extractall()
    def caribbeanleague_csv(self):
        link = "https://cricsheet.org/downloads/cpl_csv.zip"
        link = requests.get(link)
        zip = zipfile.ZipFile(io.BytesIO(link.content))
        zip.extractall()
    def caribbeanleague_csv(self):
        link = "https://cricsheet.org/downloads/cpl_csv2.zip"
        link = requests.get(link)
        zip = zipfile.ZipFile(io.BytesIO(link.content))
        zip.extractall()
    def IPL_csv(self):
        link = "https://cricsheet.org/downloads/ipl_csv.zip"
        link = requests.get(link)
        zip = zipfile.ZipFile(io.BytesIO(link.content))
        zip.extractall()
    def IPL_csv2(self):
        link = "https://cricsheet.org/downloads/ipl_csv2.zip"
        link = requests.get(link)
        zip = zipfile.ZipFile(io.BytesIO(link.content))
        zip.extractall()
    def lankaleague_csv(self):
        link = "https://cricsheet.org/downloads/lpl_csv.zip"
        link = requests.get(link)
        zip = zipfile.ZipFile(io.BytesIO(link.content))
        zip.extractall()
    def lankaleague_csv2(self):
        link = "https://cricsheet.org/downloads/lpl_csv2.zip"
        link = requests.get(link)
        zip = zipfile.ZipFile(io.BytesIO(link.content))
        zip.extractall()
    def pakistanleague_csv(self):
        link = "https://cricsheet.org/downloads/psl_csv.zip"
        link = requests.get(link)
        zip = zipfile.ZipFile(io.BytesIO(link.content))
        zip.extractall()
    def pakistanleague_csv2(self):
        link = "https://cricsheet.org/downloads/psl_csv2.zip"
        link = requests.get(link)
        zip = zipfile.ZipFile(io.BytesIO(link.content))
        zip.extractall()
    def womensbigbashleague_csv(self):
        link = "https://cricsheet.org/downloads/wbb_csv.zip"
        link = requests.get(link)
        zip = zipfile.ZipFile(io.BytesIO(link.content))
        zip.extractall()
    def womensbigbashleague_csv2(self):
        link = "https://cricsheet.org/downloads/wbb_csv2.zip"
        link = requests.get(link)
        zip = zipfile.ZipFile(io.BytesIO(link.content))
        zip.extractall()
    def womenst20_csv(self):
        link = "https://cricsheet.org/downloads/wtc_csv.zip"
        link = requests.get(link)
        zip = zipfile.ZipFile(io.BytesIO(link.content))
        zip.extractall()
    def womenst20_csv2(self):
        link = "https://cricsheet.org/downloads/wtc_csv2.zip"
        link = requests.get(link)
        zip = zipfile.ZipFile(io.BytesIO(link.content))
        zip.extractall()
    def recent_csv(self, gender, days):
        if gender == "both" or gender == "all":
            if days == 2:
                link = "https://cricsheet.org/downloads/recently_added_2_csv.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
            if days == 7:
                link = "https://cricsheet.org/downloads/recently_added_7_csv.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
            if days == 30:
                link = "https://cricsheet.org/downloads/recently_added_30_csv.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
        if gender == "women" or gender == "women":
            if days == 2:
                link = "https://cricsheet.org/downloads/recently_added_2_female_csv.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
            if days == 7:
                link = "https://cricsheet.org/downloads/recently_added_7_female_csv.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
            if days == 30:
                link = "https://cricsheet.org/downloads/recently_added_30_female_csv.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
        if gender == "men" or gender == "male":
            if days == 2:
                link = "https://cricsheet.org/downloads/recently_added_2_male_csv.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
            if days == 7:
                link = "https://cricsheet.org/downloads/recently_added_7_male_csv.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
            if days == 30:
                link = "https://cricsheet.org/downloads/recently_added_30_male_csv.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
                
    def recent_csv2(self, gender, days):
        if gender == "both" or gender == "all":
            if days == 2:
                link = "https://cricsheet.org/downloads/recently_added_2_csv2.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
            if days == 7:
                link = "https://cricsheet.org/downloads/recently_added_7_csv2.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
            if days == 30:
                link = "https://cricsheet.org/downloads/recently_added_30_csv2.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
        if gender == "women" or gender == "women":
            if days == 2:
                link = "https://cricsheet.org/downloads/recently_added_2_female_csv2.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
            if days == 7:
                link = "https://cricsheet.org/downloads/recently_added_7_female_csv2.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
            if days == 30:
                link = "https://cricsheet.org/downloads/recently_added_30_female_csv2.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
        if gender == "men" or gender == "male":
            if days == 2:
                link = "https://cricsheet.org/downloads/recently_added_2_male_csv2.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
            if days == 7:
                link = "https://cricsheet.org/downloads/recently_added_7_male_csv2.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
            if days == 30:
                link = "https://cricsheet.org/downloads/recently_added_30_male_csv2.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()

    def recent_json(self, gender, days):
        if gender == "both" or gender == "all":
            if days == 2:
                link = "https://cricsheet.org/downloads/recently_added_2_json.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
            if days == 7:
                link = "https://cricsheet.org/downloads/recently_added_7_json.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
            if days == 30:
                link = "https://cricsheet.org/downloads/recently_added_30_json.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
        if gender == "women" or gender == "women":
            if days == 2:
                link = "https://cricsheet.org/downloads/recently_added_2_female_json.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
            if days == 7:
                link = "https://cricsheet.org/downloads/recently_added_7_female_json.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
            if days == 30:
                link = "https://cricsheet.org/downloads/recently_added_30_female_json.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
        if gender == "men" or gender == "male":
            if days == 2:
                link = "https://cricsheet.org/downloads/recently_added_2_male_json.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
            if days == 7:
                link = "https://cricsheet.org/downloads/recently_added_7_male_json.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
            if days == 30:
                link = "https://cricsheet.org/downloads/recently_added_30_male_json.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()

    def recent_yaml(self, gender, days):
        if gender == "both" or gender == "all":
            if days == 2:
                link = "https://cricsheet.org/downloads/recently_added_2.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
            if days == 7:
                link = "https://cricsheet.org/downloads/recently_added_7.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
            if days == 30:
                link = "https://cricsheet.org/downloads/recently_added_30.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
        if gender == "women" or gender == "women":
            if days == 2:
                link = "https://cricsheet.org/downloads/recently_added_2_female.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
            if days == 7:
                link = "https://cricsheet.org/downloads/recently_added_7_female.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
            if days == 30:
                link = "https://cricsheet.org/downloads/recently_added_30_female.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
        if gender == "men" or gender == "male":
            if days == 2:
                link = "https://cricsheet.org/downloads/recently_added_2_male.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
            if days == 7:
                link = "https://cricsheet.org/downloads/recently_added_7_male.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
            if days == 30:
                link = "https://cricsheet.org/downloads/recently_added_30_male.zip"
                link = requests.get(link)
                zip = zipfile.ZipFile(io.BytesIO(link.content))
                zip.extractall()
Cricsheet().recent_csv(gender="women", days=7)



import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import requests
from bs4 import BeautifulSoup
import geocoder


class Scoreboard(object):

    def __init__(self):
        self.url = "https://www.espncricinfo.com/live-cricket-score"
        self.page = requests.get(self.url)
        self.soup = BeautifulSoup(self.page.content, 'html.parser')

    def scores(self):
        data = self.soup.find_all("div", class_="ds-px-4 ds-py-3")
        text_list = []
        for data in data:
            for i in data:
                for element in i:
                    text_list.append(element.text)
        for i in text_list:
            if i == '':
                text_list.remove(i)
        return pd.Series(text_list)

    def scores_df(self):
        data = self.soup.find_all("div", class_="ds-px-4 ds-py-3")
        text_list = []
        for data in data:
            for i in data:
                for element in i:
                    text_list.append(element.text)
        for i in text_list:
            if i == '':
                text_list.remove(i)
        df = pd.Series(text_list).str.split(pat=",", expand=True)
        return df


print(Scoreboard().scores()[0])
print(Scoreboard().scores()[1])
print(Scoreboard().scores()[2])



import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import requests
from bs4 import BeautifulSoup


class Records(object):
    def __init__(self):
        a = 1

    def get_records_by_team(self, team_id, record, type, format):
        self.url = f'https://stats.espncricinfo.com/ci/engine/records/{type}/{record}.html?class={format};id={team_id};type=team'
        self.page = requests.get(self.url)
        self.soup = BeautifulSoup(self.page.content, "html.parser")
        df = pd.read_html(self.url)[0]
        return df

    def get_records_by_tournament(self, type, record, tourney_id):
        self.url = f'https://stats.espncricinfo.com/ci/engine/records/{type}/{record}.html?id={tourney_id};type=trophy'
        self.page = requests.get(self.url)
        self.soup = BeautifulSoup(self.page.content, "html.parser")
        df = pd.read_html(self.url)[0]
        return df

    def get_records_h2h(self, team_id1, team_id2, record, type):
        self.url = f'https://stats.espncricinfo.com/ci/engine/records/{type}/{record}.html?class=2;id={team_id1};id={team_id2};type=headtohead'
        self.page = requests.get(self.url)
        self.soup = BeautifulSoup(self.page.content, "html.parser")
        df = pd.read_html(self.url)[0]
        return df

    def get_records_year(self, year, record, type):
        self.url = f'https://stats.espncricinfo.com/ci/engine/records/{type}/{record}.html?class=1;id={year};type=year'
        self.page = requests.get(self.url)
        self.soup = BeautifulSoup(self.page.content, "html.parser")
        df = pd.read_html(self.url)[0]
        return df

    def get_records_ground(self, type, record, ground_id):
        self.url = f'https://stats.espncricinfo.com/ci/engine/records/{type}/{record}.html?class=2;id={ground_id};type=ground'

    def get_general_records(self, record_id):
        self.url = f'https://stats.espncricinfo.com/ci/content/records/{record_id}.html'
        self.page = requests.get(self.url)
        self.soup = BeautifulSoup(self.page.content, "html.parser")
        df = pd.read_html(self.url)[0]
        return df

    def get_ipl_records(self, format, record):
        self.url = f"https://stats.espncricinfo.com/ci/engine/records/{format}/{record_id}.html?id=14452;type=tournament"
        self.page = requests.get(self.url)
        self.soup = BeautifulSoup(self.page.content, "html.parser")
        df = pd.read_html(self.url)[0]
        return df

    def get_bbl_records(self, format, record):
        self.url = f"https://stats.espncricinfo.com/ci/engine/records/{format}/{record}.html?id=158;type=trophy"
        self.page = requests.get(self.url)
        self.soup = BeautifulSoup(self.page.content, "html.parser")
        df = pd.read_html(self.url)[0]
        return df

    def get_et20_records(self, format, record):
        self.url = f"https://stats.espncricinfo.com/ci/engine/records/{format}/{record}.html?id=113;type=trophy"
        self.page = requests.get(self.url)
        self.soup = BeautifulSoup(self.page.content, "html.parser")
        df = pd.read_html(self.url)[0]
        return df

    def get_psl_records(self, format, record):
        self.url = f"https://stats.espncricinfo.com/ci/engine/records/{format}/{record}.html?id=205;type=trophy"
        self.page = requests.get(self.url)
        self.soup = BeautifulSoup(self.page.content, "html.parser")
        df = pd.read_html(self.url)[0]
        return df

    def get_psl_records(self, format, record):
        self.url = f"https://stats.espncricinfo.com/ci/engine/records/{format}/{record}.html?id=748;type=trophy"
        self.page = requests.get(self.url)
        self.soup = BeautifulSoup(self.page.content, "html.parser")
        df = pd.read_html(self.url)[0]
        return df


print(Records().get_psl_records("batting", "most_runs_career"))



from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

VERSION = '0.0.4'
DESCRIPTION = 'Package for cricket analytics'
LONG_DESCRIPTION = 'Visualizaiton, Analysis, and more (will add later)'

# Setting up
setup(
    name="criccatapult",
    version=VERSION,
    author="Aadrij Upadya, Pradyum Chitlu",
    author_email="<adrij2005@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=['pandas', 'numpy', 'matplotlib',
                      'requests', 'bs4', 'folium', 'seaborn', 'pygame', 'fiona', 'shapely'],
    keywords=['python', 'cricket', 'sports analytics',
              'data analytics', 'visualiation', 'geospatial data', 'GIS'],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Science/Research",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)
